@@ -1,6 +1,5 @@
 // -*- mode: cpp; mode: fold -*-
 // Description								/*{{{*/
-// $Id: hashes.cc,v 1.1 2001/03/06 07:15:29 jgg Exp $
 /* ######################################################################
 
    Hashes - Simple wrapper around the hash functions
@@ -208,9 +207,7 @@ unsigned long long HashStringList::FileSize() const			/*{{{*/
 									/*}}}*/
 bool HashStringList::FileSize(unsigned long long const Size)		/*{{{*/
 {
-   std::string size;
-   strprintf(size, "%llu", Size);
-   return push_back(HashString("Checksum-FileSize", size));
+   return push_back(HashString("Checksum-FileSize", std::to_string(Size)));
 }
 									/*}}}*/
 bool HashStringList::supported(char const * const type)			/*{{{*/
